"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const CommandUtils_1 = require("../service/CommandUtils");
class Config extends command_1.Command {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Config);
            CommandUtils_1.CommandUtils.showBanner();
            flags.password = yield CommandUtils_1.CommandUtils.resolvePassword(flags.password, flags.noPassword, CommandUtils_1.CommandUtils.passwordPromptDefaultMessage, true);
            yield new symbol_bootstrap_core_1.BootstrapService().config(Object.assign(Object.assign({}, flags), { privateKeyResolver: CommandUtils_1.CommandUtils }));
        });
    }
}
exports.default = Config;
Config.description = 'Command used to set up the configuration files and the nemesis block for the current network';
Config.examples = [
    `$ symbol-bootstrap config -p dualCurrency -a demo`,
    `$ symbol-bootstrap config -p testnet -a dual --password 1234`,
    `$ echo "$MY_ENV_VAR_PASSWORD" | symbol-bootstrap config -p testnet -a dual`,
];
Config.flags = {
    help: CommandUtils_1.CommandUtils.helpFlag,
    target: CommandUtils_1.CommandUtils.targetFlag,
    password: CommandUtils_1.CommandUtils.passwordFlag,
    noPassword: CommandUtils_1.CommandUtils.noPasswordFlag,
    preset: command_1.flags.string({
        char: 'p',
        description: `The network preset. It can be provided via custom preset or cli parameter. ${'If not provided, the value is resolved from the target/preset.yml file.'}`,
    }),
    assembly: command_1.flags.string({
        char: 'a',
        description: `The assembly that define the node(s) layout. It can be provided via custom preset or cli parameter. ${'If not provided, the value is resolved from the target/preset.yml file.'}`,
    }),
    customPreset: command_1.flags.string({
        char: 'c',
        description: `External preset file. Values in this file will override the provided presets.`,
    }),
    reset: command_1.flags.boolean({
        char: 'r',
        description: 'It resets the configuration generating a new one.',
        default: symbol_bootstrap_core_1.ConfigService.defaultParams.reset,
    }),
    upgrade: command_1.flags.boolean({
        description: `It regenerates the configuration reusing the previous keys. Use this flag when upgrading the version of bootstrap to keep your node up to date without dropping the local data. Backup the target folder before upgrading.`,
        default: symbol_bootstrap_core_1.ConfigService.defaultParams.reset,
    }),
    report: command_1.flags.boolean({
        description: 'It generates reStructuredText (.rst) reports describing the configuration of each node.',
        default: symbol_bootstrap_core_1.ConfigService.defaultParams.report,
    }),
    user: command_1.flags.string({
        char: 'u',
        description: `User used to run docker images when creating configuration files like certificates or nemesis block. "${symbol_bootstrap_core_1.BootstrapUtils.CURRENT_USER}" means the current user.`,
        default: symbol_bootstrap_core_1.BootstrapUtils.CURRENT_USER,
    }),
};
//# sourceMappingURL=config.js.map