"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const path_1 = require("path");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const CommandUtils_1 = require("../service/CommandUtils");
const logger = symbol_bootstrap_core_1.LoggerFactory.getLogger(symbol_bootstrap_core_1.LogType.System);
class Decrypt extends command_1.Command {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Decrypt);
            if (!fs_1.existsSync(flags.source)) {
                throw new symbol_bootstrap_core_1.KnownError(`Source file ${flags.source} does not exist!`);
            }
            if (fs_1.existsSync(flags.destination)) {
                throw new symbol_bootstrap_core_1.KnownError(`Destination file ${flags.destination} already exists!`);
            }
            const password = yield CommandUtils_1.CommandUtils.resolvePassword(flags.password, false, `Enter the password to use to decrypt the source file into the destination file. Keep this password in a secure place!`, false);
            const data = yield symbol_bootstrap_core_1.BootstrapUtils.loadYaml(flags.source, password);
            yield symbol_bootstrap_core_1.BootstrapUtils.mkdir(path_1.dirname(flags.destination));
            yield symbol_bootstrap_core_1.BootstrapUtils.writeYaml(flags.destination, data, '');
            logger.info(`Decrypted file ${flags.destination} has been created! Any private keys on this file are now in plain text. Remember to remove the file!`);
        });
    }
}
exports.default = Decrypt;
Decrypt.description = `It decrypts a yml file using the provided password. The source file can be a custom preset file, a preset.yml file or an addresses.yml.

The main use case of this command is to verify private keys in encrypted files after encrypting a custom preset or running a bootstrap command with a provided --password.`;
Decrypt.examples = [
    `
$ symbol-bootstrap start --password 1234 --preset testnet --assembly dual --customPreset decrypted-custom-preset.yml --detached
$ symbol-bootstrap decrypt --password 1234 --source target/addresses.yml --destination plain-addresses.yml
$ symbol-bootstrap decrypt --password 1234 --source encrypted-custom-preset.yml --destination plain-custom-preset.yml
$ cat plain-addresses.yml
$ cat plain-custom-preset.yml
$ rm plain-addresses.yml
$ rm plain-custom-preset.yml
        `,
    `
$ symbol-bootstrap start --preset testnet --assembly dual --customPreset decrypted-custom-preset.yml --detached
> password prompt
$ symbol-bootstrap decrypt --source target/addresses.yml --destination plain-addresses.yml
> password prompt (enter the same password)
$ symbol-bootstrap decrypt --source encrypted-custom-preset.yml --destination plain-custom-preset.yml
> password prompt (enter the same password)
$ cat plain-addresses.yml
$ cat plain-custom-preset.yml
$ rm plain-addresses.yml
$ rm plain-custom-preset.yml`,
    `
$ echo "$MY_ENV_VAR_PASSWORD" | symbol-bootstrap decrypt --source target/addresses.yml --destination plain-addresses.yml
`,
];
Decrypt.flags = {
    help: CommandUtils_1.CommandUtils.helpFlag,
    source: command_1.flags.string({
        description: `The source encrypted yml file to be decrypted.`,
        required: true,
    }),
    destination: command_1.flags.string({
        description: `The destination decrypted file to create. The destination file must not exist.`,
        required: true,
    }),
    password: CommandUtils_1.CommandUtils.getPasswordFlag(`The password to use to decrypt the source file into the destination file. Bootstrap prompts for a password by default, can be provided in the command line (--password=XXXX) or disabled in the command line (--noPassword).`),
};
//# sourceMappingURL=decrypt.js.map