"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const path_1 = require("path");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const service_1 = require("../service");
const logger = symbol_bootstrap_core_1.LoggerFactory.getLogger(symbol_bootstrap_core_1.LogType.System);
class Encrypt extends command_1.Command {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Encrypt);
            if (!fs_1.existsSync(flags.source)) {
                throw new symbol_bootstrap_core_1.KnownError(`Source file ${flags.source} does not exist!`);
            }
            if (fs_1.existsSync(flags.destination)) {
                throw new symbol_bootstrap_core_1.KnownError(`Destination file ${flags.destination} already exists!`);
            }
            const password = yield service_1.CommandUtils.resolvePassword(flags.password, false, `Enter the password used to decrypt the source file into the destination file. Keep this password in a secure place!`, false);
            const data = yield symbol_bootstrap_core_1.BootstrapUtils.loadYaml(flags.source, false);
            if (symbol_bootstrap_core_1.CryptoUtils.encryptedCount(data) > 0) {
                throw new symbol_bootstrap_core_1.KnownError(`Source file ${flags.source} is already encrypted. If you want to decrypt it use the decrypt command.`);
            }
            yield symbol_bootstrap_core_1.BootstrapUtils.mkdir(path_1.dirname(flags.destination));
            yield symbol_bootstrap_core_1.BootstrapUtils.writeYaml(flags.destination, data, password);
            logger.info(`Encrypted file ${flags.destination} has been created!`);
        });
    }
}
exports.default = Encrypt;
Encrypt.description = `It encrypts a yml file using the provided password. The source files would be a custom preset file, a preset.yml file or an addresses.yml.

The main use case of this command is encrypting custom presets files. If your custom preset contains private keys, it's highly recommended to encrypt it and use provide --password when starting or configuring the node with Bootstrap.`;
Encrypt.examples = [
    `
$ symbol-bootstrap encrypt --source plain-custom-preset.yml --destination encrypted-custom-preset.yml
> password prompt
$ symbol-bootstrap start --preset testnet --assembly dual --customPreset encrypted-custom-preset.yml
> password prompt (enter the same password)
        `,
    `
$ symbol-bootstrap encrypt --password 1234 --source plain-custom-preset.yml --destination encrypted-custom-preset.yml
$ symbol-bootstrap start --password 1234 --preset testnet --assembly dual --customPreset encrypted-custom-preset.yml
`,
    `
 $ echo "$MY_ENV_VAR_PASSWORD" | symbol-bootstrap encrypt --source plain-custom-preset.yml --destination encrypted-custom-preset.yml
 `,
];
Encrypt.flags = {
    help: service_1.CommandUtils.helpFlag,
    source: command_1.flags.string({
        description: `The source plain yml file to be encrypted. If this file is encrypted, the command will raise an error.`,
        required: true,
    }),
    destination: command_1.flags.string({
        description: `The destination encrypted file to create. The destination file must not exist.`,
        required: true,
    }),
    password: service_1.CommandUtils.getPasswordFlag(`The password to use to encrypt the source file into the destination file. Bootstrap prompts for a password by default, can be provided in the command line (--password=XXXX) or disabled in the command line (--noPassword).`),
};
//# sourceMappingURL=encrypt.js.map