"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const service_1 = require("../service");
const logger = symbol_bootstrap_core_1.LoggerFactory.getLogger(symbol_bootstrap_core_1.LogType.System);
class UpdateVotingKeys extends command_1.Command {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(UpdateVotingKeys);
            service_1.CommandUtils.showBanner();
            const password = false;
            const target = flags.target;
            const configLoader = new symbol_bootstrap_core_1.ConfigLoader();
            const addressesLocation = configLoader.getGeneratedAddressLocation(target);
            const presetData = configLoader.loadExistingPresetData(target, password);
            const addresses = configLoader.loadExistingAddresses(target, password);
            const privateKeySecurityMode = symbol_bootstrap_core_1.CryptoUtils.getPrivateKeySecurityMode(presetData.privateKeySecurityMode);
            const finalizationEpoch = flags.finalizationEpoch || (yield new symbol_bootstrap_core_1.RemoteNodeService().resolveCurrentFinalizationEpoch(presetData, false));
            const votingKeyUpgrade = (yield Promise.all((presetData.nodes || []).map((nodePreset, index) => {
                var _a;
                const nodeAccount = (_a = addresses.nodes) === null || _a === void 0 ? void 0 : _a[index];
                if (!nodeAccount) {
                    throw new Error(`There is not node in addresses at index ${index}`);
                }
                return new symbol_bootstrap_core_1.VotingService({
                    target,
                    user: flags.user,
                }).run(presetData, nodeAccount, nodePreset, finalizationEpoch, true, false);
            }))).find((f) => f);
            if (votingKeyUpgrade) {
                yield symbol_bootstrap_core_1.BootstrapUtils.writeYaml(addressesLocation, symbol_bootstrap_core_1.CryptoUtils.removePrivateKeysAccordingToSecurityMode(addresses, privateKeySecurityMode), undefined);
                logger.warn('Bootstrap has created new voting file(s). Review the logs!');
                logger.warn('');
            }
            else {
                logger.info('');
                logger.info('Voting files are up-to-date. There is nothing to upgrade');
                logger.info('');
            }
        });
    }
}
exports.default = UpdateVotingKeys;
UpdateVotingKeys.description = `It updates the voting files containing the voting keys when required.

If the node's current voting file has an end epoch close to the current network epoch, this command will create a new 'private_key_treeX.dat' that continues the current file.

By default, bootstrap creates a new voting file once the current file reaches its last month. The current network epoch is resolved from the network or you can provide it with the \`finalizationEpoch\` param.

When a new voting file is created, Bootstrap will advise running the \`link\` command again.

`;
UpdateVotingKeys.examples = [`$ symbol-bootstrap updateVotingKeys`];
UpdateVotingKeys.flags = {
    help: service_1.CommandUtils.helpFlag,
    target: service_1.CommandUtils.targetFlag,
    user: command_1.flags.string({
        char: 'u',
        description: `User used to run docker images when creating the the voting key files. "${symbol_bootstrap_core_1.BootstrapUtils.CURRENT_USER}" means the current user.`,
        default: symbol_bootstrap_core_1.BootstrapUtils.CURRENT_USER,
    }),
    finalizationEpoch: command_1.flags.integer({
        description: `The network's finalization epoch. It can be retrieved from the /chain/info rest endpoint. If not provided, the bootstrap known epoch is used.`,
    }),
};
//# sourceMappingURL=updateVotingKeys.js.map