"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandUtils = void 0;
const command_1 = require("@oclif/command");
const figlet_1 = require("figlet");
const inquirer_1 = require("inquirer");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const symbol_sdk_1 = require("symbol-sdk");
const logger = symbol_bootstrap_core_1.LoggerFactory.getLogger(symbol_bootstrap_core_1.LogType.System);
class CommandUtils {
    static showBanner() {
        console.log(figlet_1.textSync('symbol-bootstrap', { horizontalLayout: 'fitted' }));
    }
    static getPasswordFlag(description) {
        return command_1.flags.string({
            description: description,
            parse(input) {
                const result = !input || CommandUtils.isValidPassword(input);
                if (result === true)
                    return input;
                throw new Error(`--password is invalid, ${result}`);
            },
        });
    }
    static isValidPassword(input) {
        if (!input || input === '') {
            return true;
        }
        if (input.length >= 4)
            return true;
        return `Password must have at least 4 characters but got ${input.length}`;
    }
    static resolvePrivateKey(networkType, account, keyName, nodeName, operationDescription) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!account) {
                return '';
            }
            if (!account.privateKey) {
                while (true) {
                    console.log();
                    console.log(`${keyName} private key is required when ${operationDescription}.`);
                    const address = symbol_sdk_1.PublicAccount.createFromPublicKey(account.publicKey, networkType).address.plain();
                    const nodeDescription = nodeName === '' ? `of` : `of the Node's '${nodeName}'`;
                    const responses = yield inquirer_1.prompt([
                        {
                            name: 'value',
                            message: `Enter the 64 HEX private key ${nodeDescription} ${keyName} account with Address: ${address} and Public Key: ${account.publicKey}:`,
                            type: 'password',
                            mask: '*',
                            validate: symbol_bootstrap_core_1.BootstrapUtils.isValidPrivateKey,
                        },
                    ]);
                    const privateKey = responses.value === '' ? undefined : responses.value.toUpperCase();
                    if (!privateKey) {
                        console.log('Please provide the private key.');
                    }
                    else {
                        const enteredAccount = symbol_sdk_1.Account.createFromPrivateKey(privateKey, networkType);
                        if (enteredAccount.publicKey.toUpperCase() !== account.publicKey.toUpperCase()) {
                            console.log(`Invalid private key. Expected address is ${address} but you provided the private key for address ${enteredAccount.address.plain()}.\n`);
                            console.log(`Please re-enter private key.`);
                        }
                        else {
                            account.privateKey = privateKey;
                            return privateKey;
                        }
                    }
                }
            }
            return account.privateKey.toUpperCase();
        });
    }
    static resolvePassword(providedPassword, noPassword, message, log) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!providedPassword) {
                if (noPassword) {
                    if (log)
                        logger.warn(`Password has not been provided (--noPassword)! It's recommended to use one for security!`);
                    return undefined;
                }
                const responses = yield inquirer_1.prompt([
                    {
                        name: 'password',
                        mask: '*',
                        message: message,
                        type: 'password',
                        validate: CommandUtils.isValidPassword,
                    },
                ]);
                if (responses.password === '' || !responses.password) {
                    if (log)
                        logger.warn(`Password has not been provided (empty text)! It's recommended to use one for security!`);
                    return undefined;
                }
                if (log)
                    logger.info(`Password has been provided`);
                return responses.password;
            }
            if (log)
                logger.info(`Password has been provided`);
            return providedPassword;
        });
    }
}
exports.CommandUtils = CommandUtils;
CommandUtils.passwordPromptDefaultMessage = `Enter the password used to encrypt and decrypt custom presets, addresses.yml, and preset.yml files. When providing a password, private keys will be encrypted. Keep this password in a secure place!`;
CommandUtils.helpFlag = command_1.flags.help({ char: 'h', description: 'It shows the help of this command.' });
CommandUtils.targetFlag = command_1.flags.string({
    char: 't',
    description: 'The target folder where the symbol-bootstrap network is generated',
    default: symbol_bootstrap_core_1.BootstrapUtils.defaultTargetFolder,
});
CommandUtils.passwordFlag = CommandUtils.getPasswordFlag(`A password used to encrypt and decrypt private keys in preset files like addresses.yml and preset.yml. Bootstrap prompts for a password by default, can be provided in the command line (--password=XXXX) or disabled in the command line (--noPassword).`);
CommandUtils.noPasswordFlag = command_1.flags.boolean({
    description: 'When provided, Bootstrap will not use a password, so private keys will be stored in plain text. Use with caution.',
    default: false,
});
//# sourceMappingURL=CommandUtils.js.map