"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinkService = void 0;
const inquirer_1 = require("inquirer");
const symbol_bootstrap_core_1 = require("symbol-bootstrap-core");
const symbol_sdk_1 = require("symbol-sdk");
const AnnounceService_1 = require("./AnnounceService");
const logger = symbol_bootstrap_core_1.LoggerFactory.getLogger(symbol_bootstrap_core_1.LogType.System);
class LinkService {
    constructor(params) {
        this.params = params;
        this.confirmUnlink = (accountName, alreadyLinkedAccount, print) => __awaiter(this, void 0, void 0, function* () {
            if (this.params.removeOldLinked === undefined) {
                return (this.params.ready ||
                    (yield inquirer_1.prompt([
                        {
                            name: 'value',
                            message: `Do you want to unlink the old ${accountName} ${print(alreadyLinkedAccount)}?`,
                            type: 'confirm',
                            default: false,
                        },
                    ])).value);
            }
            return this.params.removeOldLinked;
        });
        this.configLoader = new symbol_bootstrap_core_1.ConfigLoader();
    }
    run(passedPresetData, passedAddresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const presetData = passedPresetData !== null && passedPresetData !== void 0 ? passedPresetData : this.configLoader.loadExistingPresetData(this.params.target, this.params.password);
            const addresses = passedAddresses !== null && passedAddresses !== void 0 ? passedAddresses : this.configLoader.loadExistingAddresses(this.params.target, this.params.password);
            const customPreset = this.configLoader.loadCustomPreset(this.params.customPreset, this.params.password);
            logger.info(`${this.params.unlink ? 'Unlinking' : 'Linking'} nodes`);
            yield new AnnounceService_1.AnnounceService().announce(this.params.url, this.params.maxFee, this.params.useKnownRestGateways, this.params.ready, this.params.target, this.configLoader.mergePresets(presetData, customPreset), addresses, this);
        });
    }
    createTransactions({ presetData, nodeAccount, mainAccountInfo, deadline, maxFee, latestFinalizedBlockEpoch, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const networkType = presetData.networkType;
            const nodeName = nodeAccount.name;
            const remoteTransactionFactory = ({ publicKey }, action) => symbol_sdk_1.AccountKeyLinkTransaction.create(deadline, publicKey, action, networkType, maxFee);
            const vrfTransactionFactory = ({ publicKey }, action) => symbol_sdk_1.VrfKeyLinkTransaction.create(deadline, publicKey, action, networkType, maxFee);
            const votingKeyTransactionFactory = (account, action) => {
                return symbol_sdk_1.VotingKeyLinkTransaction.create(deadline, account.publicKey, account.startEpoch, account.endEpoch, action, networkType, 1, maxFee);
            };
            logger.info(`Creating transactions for node: ${nodeName}, ca/main account: ${mainAccountInfo.address.plain()}`);
            const transactions = yield new symbol_bootstrap_core_1.LinkTransactionGenericFactory(logger, this.confirmUnlink, this.params).createGenericTransactions(nodeName, {
                vrf: mainAccountInfo.supplementalPublicKeys.vrf,
                remote: mainAccountInfo.supplementalPublicKeys.linked,
                voting: mainAccountInfo.supplementalPublicKeys.voting,
            }, nodeAccount, latestFinalizedBlockEpoch || presetData.lastKnownNetworkEpoch, remoteTransactionFactory, vrfTransactionFactory, votingKeyTransactionFactory);
            return transactions.sort((t1, t2) => t1.linkAction - t2.linkAction);
        });
    }
}
exports.LinkService = LinkService;
LinkService.defaultParams = {
    target: symbol_bootstrap_core_1.BootstrapUtils.defaultTargetFolder,
    useKnownRestGateways: false,
    ready: false,
    url: 'http://localhost:3000',
    maxFee: 100000,
    unlink: false,
};
//# sourceMappingURL=LinkService.js.map